from distutils.core import setup

setup(
    name        = 'tester-LX',
    version     = '10.0.2',
    py_modules  = ['tester-LX'],
    author      = 'hfpython',
    author_email = 'hfpython@headfirstlabs.com',
    url         = 'http://www.headfirstlabs.com',
    description = 'a simple printer of nested lists',
    )
